# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class Stats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'imps': 'int',
        'imps_prev': 'float',
        'click_cnt': 'int',
        'click_rate': 'float',
        'click_rate_prev': 'float',
        'cost': 'float',
        'avg_cpc': 'float',
        'conversions': 'int',
        'conversion_rate': 'float',
        'conversions_via_ad_click': 'int',
        'conversion_rate_via_ad_click': 'float',
        'all_conversions': 'int',
        'all_conversion_rate': 'float',
        'cpa': 'str',
        'conversion_value': 'str',
        'value_per_conversions': 'str',
        'conv_value_per_cost': 'float',
        'all_conv_value_per_cost': 'float',
        'conv_value_via_ad_click_per_cost': 'float',
        'all_conversion_value': 'str',
        'value_per_all_conversions': 'str',
        'conversion_value_via_ad_click': 'str',
        'value_per_conversions_via_ad_click': 'str',
        'cpa_via_ad_click': 'str',
        'all_cpa': 'str',
        'cross_device_conversions': 'int',
        'avg_deliver_rank': 'float',
        'measured_imps': 'float',
        'total_vimps': 'int',
        'measured_imps_rate': 'float',
        'vimps': 'int',
        'viewable_imps_rate': 'float',
        'in_view_rate': 'float',
        'viewable_clicks': 'float',
        'in_view_click_cnt': 'int',
        'viewable_click_rate': 'float',
        'in_view_click_rate': 'float',
        'paid_video_views': 'int',
        'paid_video_view_rate': 'float',
        'average_cpv': 'float',
        'video_views': 'int',
        'video_views_to25': 'int',
        'video_views_to50': 'int',
        'video_views_to75': 'int',
        'video_views_to95': 'int',
        'video_views_to100': 'int',
        'video_views_to3_sec': 'int',
        'video_views_to10_sec': 'int',
        'average_rate_video_viewed': 'float',
        'average_duration_video_viewed': 'float',
        'impression_share': 'float',
        'budget_impression_share_lost_rate': 'float',
        'rank_impression_share_lost_rate': 'float'
    }

    attribute_map = {
        'imps': 'imps',
        'imps_prev': 'impsPrev',
        'click_cnt': 'clickCnt',
        'click_rate': 'clickRate',
        'click_rate_prev': 'clickRatePrev',
        'cost': 'cost',
        'avg_cpc': 'avgCpc',
        'conversions': 'conversions',
        'conversion_rate': 'conversionRate',
        'conversions_via_ad_click': 'conversionsViaAdClick',
        'conversion_rate_via_ad_click': 'conversionRateViaAdClick',
        'all_conversions': 'allConversions',
        'all_conversion_rate': 'allConversionRate',
        'cpa': 'cpa',
        'conversion_value': 'conversionValue',
        'value_per_conversions': 'valuePerConversions',
        'conv_value_per_cost': 'convValuePerCost',
        'all_conv_value_per_cost': 'allConvValuePerCost',
        'conv_value_via_ad_click_per_cost': 'convValueViaAdClickPerCost',
        'all_conversion_value': 'allConversionValue',
        'value_per_all_conversions': 'valuePerAllConversions',
        'conversion_value_via_ad_click': 'conversionValueViaAdClick',
        'value_per_conversions_via_ad_click': 'valuePerConversionsViaAdClick',
        'cpa_via_ad_click': 'cpaViaAdClick',
        'all_cpa': 'allCpa',
        'cross_device_conversions': 'crossDeviceConversions',
        'avg_deliver_rank': 'avgDeliverRank',
        'measured_imps': 'measuredImps',
        'total_vimps': 'totalVimps',
        'measured_imps_rate': 'measuredImpsRate',
        'vimps': 'vimps',
        'viewable_imps_rate': 'viewableImpsRate',
        'in_view_rate': 'inViewRate',
        'viewable_clicks': 'viewableClicks',
        'in_view_click_cnt': 'inViewClickCnt',
        'viewable_click_rate': 'viewableClickRate',
        'in_view_click_rate': 'inViewClickRate',
        'paid_video_views': 'paidVideoViews',
        'paid_video_view_rate': 'paidVideoViewRate',
        'average_cpv': 'averageCpv',
        'video_views': 'videoViews',
        'video_views_to25': 'videoViewsTo25',
        'video_views_to50': 'videoViewsTo50',
        'video_views_to75': 'videoViewsTo75',
        'video_views_to95': 'videoViewsTo95',
        'video_views_to100': 'videoViewsTo100',
        'video_views_to3_sec': 'videoViewsTo3Sec',
        'video_views_to10_sec': 'videoViewsTo10Sec',
        'average_rate_video_viewed': 'averageRateVideoViewed',
        'average_duration_video_viewed': 'averageDurationVideoViewed',
        'impression_share': 'impressionShare',
        'budget_impression_share_lost_rate': 'budgetImpressionShareLostRate',
        'rank_impression_share_lost_rate': 'rankImpressionShareLostRate'
    }

    def __init__(self, imps=None, imps_prev=None, click_cnt=None, click_rate=None, click_rate_prev=None, cost=None, avg_cpc=None, conversions=None, conversion_rate=None, conversions_via_ad_click=None, conversion_rate_via_ad_click=None, all_conversions=None, all_conversion_rate=None, cpa=None, conversion_value=None, value_per_conversions=None, conv_value_per_cost=None, all_conv_value_per_cost=None, conv_value_via_ad_click_per_cost=None, all_conversion_value=None, value_per_all_conversions=None, conversion_value_via_ad_click=None, value_per_conversions_via_ad_click=None, cpa_via_ad_click=None, all_cpa=None, cross_device_conversions=None, avg_deliver_rank=None, measured_imps=None, total_vimps=None, measured_imps_rate=None, vimps=None, viewable_imps_rate=None, in_view_rate=None, viewable_clicks=None, in_view_click_cnt=None, viewable_click_rate=None, in_view_click_rate=None, paid_video_views=None, paid_video_view_rate=None, average_cpv=None, video_views=None, video_views_to25=None, video_views_to50=None, video_views_to75=None, video_views_to95=None, video_views_to100=None, video_views_to3_sec=None, video_views_to10_sec=None, average_rate_video_viewed=None, average_duration_video_viewed=None, impression_share=None, budget_impression_share_lost_rate=None, rank_impression_share_lost_rate=None, local_vars_configuration=None):  # noqa: E501
        """Stats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._imps = None
        self._imps_prev = None
        self._click_cnt = None
        self._click_rate = None
        self._click_rate_prev = None
        self._cost = None
        self._avg_cpc = None
        self._conversions = None
        self._conversion_rate = None
        self._conversions_via_ad_click = None
        self._conversion_rate_via_ad_click = None
        self._all_conversions = None
        self._all_conversion_rate = None
        self._cpa = None
        self._conversion_value = None
        self._value_per_conversions = None
        self._conv_value_per_cost = None
        self._all_conv_value_per_cost = None
        self._conv_value_via_ad_click_per_cost = None
        self._all_conversion_value = None
        self._value_per_all_conversions = None
        self._conversion_value_via_ad_click = None
        self._value_per_conversions_via_ad_click = None
        self._cpa_via_ad_click = None
        self._all_cpa = None
        self._cross_device_conversions = None
        self._avg_deliver_rank = None
        self._measured_imps = None
        self._total_vimps = None
        self._measured_imps_rate = None
        self._vimps = None
        self._viewable_imps_rate = None
        self._in_view_rate = None
        self._viewable_clicks = None
        self._in_view_click_cnt = None
        self._viewable_click_rate = None
        self._in_view_click_rate = None
        self._paid_video_views = None
        self._paid_video_view_rate = None
        self._average_cpv = None
        self._video_views = None
        self._video_views_to25 = None
        self._video_views_to50 = None
        self._video_views_to75 = None
        self._video_views_to95 = None
        self._video_views_to100 = None
        self._video_views_to3_sec = None
        self._video_views_to10_sec = None
        self._average_rate_video_viewed = None
        self._average_duration_video_viewed = None
        self._impression_share = None
        self._budget_impression_share_lost_rate = None
        self._rank_impression_share_lost_rate = None
        self.discriminator = None

        self.imps = imps
        self.imps_prev = imps_prev
        self.click_cnt = click_cnt
        self.click_rate = click_rate
        self.click_rate_prev = click_rate_prev
        self.cost = cost
        self.avg_cpc = avg_cpc
        self.conversions = conversions
        self.conversion_rate = conversion_rate
        self.conversions_via_ad_click = conversions_via_ad_click
        self.conversion_rate_via_ad_click = conversion_rate_via_ad_click
        self.all_conversions = all_conversions
        self.all_conversion_rate = all_conversion_rate
        self.cpa = cpa
        self.conversion_value = conversion_value
        self.value_per_conversions = value_per_conversions
        self.conv_value_per_cost = conv_value_per_cost
        self.all_conv_value_per_cost = all_conv_value_per_cost
        self.conv_value_via_ad_click_per_cost = conv_value_via_ad_click_per_cost
        self.all_conversion_value = all_conversion_value
        self.value_per_all_conversions = value_per_all_conversions
        self.conversion_value_via_ad_click = conversion_value_via_ad_click
        self.value_per_conversions_via_ad_click = value_per_conversions_via_ad_click
        self.cpa_via_ad_click = cpa_via_ad_click
        self.all_cpa = all_cpa
        self.cross_device_conversions = cross_device_conversions
        self.avg_deliver_rank = avg_deliver_rank
        self.measured_imps = measured_imps
        self.total_vimps = total_vimps
        self.measured_imps_rate = measured_imps_rate
        self.vimps = vimps
        self.viewable_imps_rate = viewable_imps_rate
        self.in_view_rate = in_view_rate
        self.viewable_clicks = viewable_clicks
        self.in_view_click_cnt = in_view_click_cnt
        self.viewable_click_rate = viewable_click_rate
        self.in_view_click_rate = in_view_click_rate
        self.paid_video_views = paid_video_views
        self.paid_video_view_rate = paid_video_view_rate
        self.average_cpv = average_cpv
        self.video_views = video_views
        self.video_views_to25 = video_views_to25
        self.video_views_to50 = video_views_to50
        self.video_views_to75 = video_views_to75
        self.video_views_to95 = video_views_to95
        self.video_views_to100 = video_views_to100
        self.video_views_to3_sec = video_views_to3_sec
        self.video_views_to10_sec = video_views_to10_sec
        self.average_rate_video_viewed = average_rate_video_viewed
        self.average_duration_video_viewed = average_duration_video_viewed
        self.impression_share = impression_share
        self.budget_impression_share_lost_rate = budget_impression_share_lost_rate
        self.rank_impression_share_lost_rate = rank_impression_share_lost_rate

    @property
    def imps(self):
        """Gets the imps of this Stats.  # noqa: E501

        <div lang=\"ja\">インプレッション数</div> <div lang=\"en\">Number of impressions</div>   # noqa: E501

        :return: The imps of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._imps

    @imps.setter
    def imps(self, imps):
        """Sets the imps of this Stats.

        <div lang=\"ja\">インプレッション数</div> <div lang=\"en\">Number of impressions</div>   # noqa: E501

        :param imps: The imps of this Stats.  # noqa: E501
        :type: int
        """

        self._imps = imps

    @property
    def imps_prev(self):
        """Gets the imps_prev of this Stats.  # noqa: E501

        <div lang=\"ja\">インプレッション数（旧）</div> <div lang=\"en\">Impressions (previous)</div>   # noqa: E501

        :return: The imps_prev of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._imps_prev

    @imps_prev.setter
    def imps_prev(self, imps_prev):
        """Sets the imps_prev of this Stats.

        <div lang=\"ja\">インプレッション数（旧）</div> <div lang=\"en\">Impressions (previous)</div>   # noqa: E501

        :param imps_prev: The imps_prev of this Stats.  # noqa: E501
        :type: float
        """

        self._imps_prev = imps_prev

    @property
    def click_cnt(self):
        """Gets the click_cnt of this Stats.  # noqa: E501

        <div lang=\"ja\">クリック数</div> <div lang=\"en\">Number of clicks</div>   # noqa: E501

        :return: The click_cnt of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._click_cnt

    @click_cnt.setter
    def click_cnt(self, click_cnt):
        """Sets the click_cnt of this Stats.

        <div lang=\"ja\">クリック数</div> <div lang=\"en\">Number of clicks</div>   # noqa: E501

        :param click_cnt: The click_cnt of this Stats.  # noqa: E501
        :type: int
        """

        self._click_cnt = click_cnt

    @property
    def click_rate(self):
        """Gets the click_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">クリック率</div> <div lang=\"en\">Click through rate</div>   # noqa: E501

        :return: The click_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._click_rate

    @click_rate.setter
    def click_rate(self, click_rate):
        """Sets the click_rate of this Stats.

        <div lang=\"ja\">クリック率</div> <div lang=\"en\">Click through rate</div>   # noqa: E501

        :param click_rate: The click_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._click_rate = click_rate

    @property
    def click_rate_prev(self):
        """Gets the click_rate_prev of this Stats.  # noqa: E501

        <div lang=\"ja\">クリック率（旧）</div> <div lang=\"en\">CTR (previous)</div>   # noqa: E501

        :return: The click_rate_prev of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._click_rate_prev

    @click_rate_prev.setter
    def click_rate_prev(self, click_rate_prev):
        """Sets the click_rate_prev of this Stats.

        <div lang=\"ja\">クリック率（旧）</div> <div lang=\"en\">CTR (previous)</div>   # noqa: E501

        :param click_rate_prev: The click_rate_prev of this Stats.  # noqa: E501
        :type: float
        """

        self._click_rate_prev = click_rate_prev

    @property
    def cost(self):
        """Gets the cost of this Stats.  # noqa: E501

        <div lang=\"ja\">コスト</div> <div lang=\"en\">Cost</div>   # noqa: E501

        :return: The cost of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """Sets the cost of this Stats.

        <div lang=\"ja\">コスト</div> <div lang=\"en\">Cost</div>   # noqa: E501

        :param cost: The cost of this Stats.  # noqa: E501
        :type: float
        """

        self._cost = cost

    @property
    def avg_cpc(self):
        """Gets the avg_cpc of this Stats.  # noqa: E501

        <div lang=\"ja\">平均CPC</div> <div lang=\"en\">Avg. CPC</div>   # noqa: E501

        :return: The avg_cpc of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._avg_cpc

    @avg_cpc.setter
    def avg_cpc(self, avg_cpc):
        """Sets the avg_cpc of this Stats.

        <div lang=\"ja\">平均CPC</div> <div lang=\"en\">Avg. CPC</div>   # noqa: E501

        :param avg_cpc: The avg_cpc of this Stats.  # noqa: E501
        :type: float
        """

        self._avg_cpc = avg_cpc

    @property
    def conversions(self):
        """Gets the conversions of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン数</div> <div lang=\"en\">Conversions</div>   # noqa: E501

        :return: The conversions of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._conversions

    @conversions.setter
    def conversions(self, conversions):
        """Sets the conversions of this Stats.

        <div lang=\"ja\">コンバージョン数</div> <div lang=\"en\">Conversions</div>   # noqa: E501

        :param conversions: The conversions of this Stats.  # noqa: E501
        :type: int
        """

        self._conversions = conversions

    @property
    def conversion_rate(self):
        """Gets the conversion_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン率</div> <div lang=\"en\">Conv. rate</div>   # noqa: E501

        :return: The conversion_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._conversion_rate

    @conversion_rate.setter
    def conversion_rate(self, conversion_rate):
        """Sets the conversion_rate of this Stats.

        <div lang=\"ja\">コンバージョン率</div> <div lang=\"en\">Conv. rate</div>   # noqa: E501

        :param conversion_rate: The conversion_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._conversion_rate = conversion_rate

    @property
    def conversions_via_ad_click(self):
        """Gets the conversions_via_ad_click of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン数（クリック経由）</div> <div lang=\"en\">Conversions (via click)</div>   # noqa: E501

        :return: The conversions_via_ad_click of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._conversions_via_ad_click

    @conversions_via_ad_click.setter
    def conversions_via_ad_click(self, conversions_via_ad_click):
        """Sets the conversions_via_ad_click of this Stats.

        <div lang=\"ja\">コンバージョン数（クリック経由）</div> <div lang=\"en\">Conversions (via click)</div>   # noqa: E501

        :param conversions_via_ad_click: The conversions_via_ad_click of this Stats.  # noqa: E501
        :type: int
        """

        self._conversions_via_ad_click = conversions_via_ad_click

    @property
    def conversion_rate_via_ad_click(self):
        """Gets the conversion_rate_via_ad_click of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン率（クリック経由）</div> <div lang=\"en\">Conv. rate (via click)</div>   # noqa: E501

        :return: The conversion_rate_via_ad_click of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._conversion_rate_via_ad_click

    @conversion_rate_via_ad_click.setter
    def conversion_rate_via_ad_click(self, conversion_rate_via_ad_click):
        """Sets the conversion_rate_via_ad_click of this Stats.

        <div lang=\"ja\">コンバージョン率（クリック経由）</div> <div lang=\"en\">Conv. rate (via click)</div>   # noqa: E501

        :param conversion_rate_via_ad_click: The conversion_rate_via_ad_click of this Stats.  # noqa: E501
        :type: float
        """

        self._conversion_rate_via_ad_click = conversion_rate_via_ad_click

    @property
    def all_conversions(self):
        """Gets the all_conversions of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン数（全て）</div> <div lang=\"en\">Conversions (all)</div>   # noqa: E501

        :return: The all_conversions of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._all_conversions

    @all_conversions.setter
    def all_conversions(self, all_conversions):
        """Sets the all_conversions of this Stats.

        <div lang=\"ja\">コンバージョン数（全て）</div> <div lang=\"en\">Conversions (all)</div>   # noqa: E501

        :param all_conversions: The all_conversions of this Stats.  # noqa: E501
        :type: int
        """

        self._all_conversions = all_conversions

    @property
    def all_conversion_rate(self):
        """Gets the all_conversion_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン率（全て）</div> <div lang=\"en\">Conv. rate (all)</div>   # noqa: E501

        :return: The all_conversion_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._all_conversion_rate

    @all_conversion_rate.setter
    def all_conversion_rate(self, all_conversion_rate):
        """Sets the all_conversion_rate of this Stats.

        <div lang=\"ja\">コンバージョン率（全て）</div> <div lang=\"en\">Conv. rate (all)</div>   # noqa: E501

        :param all_conversion_rate: The all_conversion_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._all_conversion_rate = all_conversion_rate

    @property
    def cpa(self):
        """Gets the cpa of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン単価</div> <div lang=\"en\">Conversion cost per acquisition</div>   # noqa: E501

        :return: The cpa of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._cpa

    @cpa.setter
    def cpa(self, cpa):
        """Sets the cpa of this Stats.

        <div lang=\"ja\">コンバージョン単価</div> <div lang=\"en\">Conversion cost per acquisition</div>   # noqa: E501

        :param cpa: The cpa of this Stats.  # noqa: E501
        :type: str
        """

        self._cpa = cpa

    @property
    def conversion_value(self):
        """Gets the conversion_value of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値</div> <div lang=\"en\">Conv. value</div>   # noqa: E501

        :return: The conversion_value of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._conversion_value

    @conversion_value.setter
    def conversion_value(self, conversion_value):
        """Sets the conversion_value of this Stats.

        <div lang=\"ja\">コンバージョンの価値</div> <div lang=\"en\">Conv. value</div>   # noqa: E501

        :param conversion_value: The conversion_value of this Stats.  # noqa: E501
        :type: str
        """

        self._conversion_value = conversion_value

    @property
    def value_per_conversions(self):
        """Gets the value_per_conversions of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値/コンバージョン数</div> <div lang=\"en\">Conv. value/conv.</div>   # noqa: E501

        :return: The value_per_conversions of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._value_per_conversions

    @value_per_conversions.setter
    def value_per_conversions(self, value_per_conversions):
        """Sets the value_per_conversions of this Stats.

        <div lang=\"ja\">コンバージョンの価値/コンバージョン数</div> <div lang=\"en\">Conv. value/conv.</div>   # noqa: E501

        :param value_per_conversions: The value_per_conversions of this Stats.  # noqa: E501
        :type: str
        """

        self._value_per_conversions = value_per_conversions

    @property
    def conv_value_per_cost(self):
        """Gets the conv_value_per_cost of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（クリック経由）/コスト</div> <div lang=\"en\">Conversions value/cost</div>   # noqa: E501

        :return: The conv_value_per_cost of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._conv_value_per_cost

    @conv_value_per_cost.setter
    def conv_value_per_cost(self, conv_value_per_cost):
        """Sets the conv_value_per_cost of this Stats.

        <div lang=\"ja\">コンバージョンの価値（クリック経由）/コスト</div> <div lang=\"en\">Conversions value/cost</div>   # noqa: E501

        :param conv_value_per_cost: The conv_value_per_cost of this Stats.  # noqa: E501
        :type: float
        """

        self._conv_value_per_cost = conv_value_per_cost

    @property
    def all_conv_value_per_cost(self):
        """Gets the all_conv_value_per_cost of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（全て）/コスト</div> <div lang=\"en\">Conv. value (all)/cost All Conv.</div>   # noqa: E501

        :return: The all_conv_value_per_cost of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._all_conv_value_per_cost

    @all_conv_value_per_cost.setter
    def all_conv_value_per_cost(self, all_conv_value_per_cost):
        """Sets the all_conv_value_per_cost of this Stats.

        <div lang=\"ja\">コンバージョンの価値（全て）/コスト</div> <div lang=\"en\">Conv. value (all)/cost All Conv.</div>   # noqa: E501

        :param all_conv_value_per_cost: The all_conv_value_per_cost of this Stats.  # noqa: E501
        :type: float
        """

        self._all_conv_value_per_cost = all_conv_value_per_cost

    @property
    def conv_value_via_ad_click_per_cost(self):
        """Gets the conv_value_via_ad_click_per_cost of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（クリック経由）/コスト</div> <div lang=\"en\">Conversions value(via ad clicks)/cost</div>   # noqa: E501

        :return: The conv_value_via_ad_click_per_cost of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._conv_value_via_ad_click_per_cost

    @conv_value_via_ad_click_per_cost.setter
    def conv_value_via_ad_click_per_cost(self, conv_value_via_ad_click_per_cost):
        """Sets the conv_value_via_ad_click_per_cost of this Stats.

        <div lang=\"ja\">コンバージョンの価値（クリック経由）/コスト</div> <div lang=\"en\">Conversions value(via ad clicks)/cost</div>   # noqa: E501

        :param conv_value_via_ad_click_per_cost: The conv_value_via_ad_click_per_cost of this Stats.  # noqa: E501
        :type: float
        """

        self._conv_value_via_ad_click_per_cost = conv_value_via_ad_click_per_cost

    @property
    def all_conversion_value(self):
        """Gets the all_conversion_value of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（全て）</div> <div lang=\"en\">Conv. value (all)</div>   # noqa: E501

        :return: The all_conversion_value of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._all_conversion_value

    @all_conversion_value.setter
    def all_conversion_value(self, all_conversion_value):
        """Sets the all_conversion_value of this Stats.

        <div lang=\"ja\">コンバージョンの価値（全て）</div> <div lang=\"en\">Conv. value (all)</div>   # noqa: E501

        :param all_conversion_value: The all_conversion_value of this Stats.  # noqa: E501
        :type: str
        """

        self._all_conversion_value = all_conversion_value

    @property
    def value_per_all_conversions(self):
        """Gets the value_per_all_conversions of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（全て）/コンバージョン数（全て）</div> <div lang=\"en\">Conv. value (all)/conv. (all)</div>   # noqa: E501

        :return: The value_per_all_conversions of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._value_per_all_conversions

    @value_per_all_conversions.setter
    def value_per_all_conversions(self, value_per_all_conversions):
        """Sets the value_per_all_conversions of this Stats.

        <div lang=\"ja\">コンバージョンの価値（全て）/コンバージョン数（全て）</div> <div lang=\"en\">Conv. value (all)/conv. (all)</div>   # noqa: E501

        :param value_per_all_conversions: The value_per_all_conversions of this Stats.  # noqa: E501
        :type: str
        """

        self._value_per_all_conversions = value_per_all_conversions

    @property
    def conversion_value_via_ad_click(self):
        """Gets the conversion_value_via_ad_click of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（クリック経由）</div> <div lang=\"en\">Conv. value (via click)</div>   # noqa: E501

        :return: The conversion_value_via_ad_click of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._conversion_value_via_ad_click

    @conversion_value_via_ad_click.setter
    def conversion_value_via_ad_click(self, conversion_value_via_ad_click):
        """Sets the conversion_value_via_ad_click of this Stats.

        <div lang=\"ja\">コンバージョンの価値（クリック経由）</div> <div lang=\"en\">Conv. value (via click)</div>   # noqa: E501

        :param conversion_value_via_ad_click: The conversion_value_via_ad_click of this Stats.  # noqa: E501
        :type: str
        """

        self._conversion_value_via_ad_click = conversion_value_via_ad_click

    @property
    def value_per_conversions_via_ad_click(self):
        """Gets the value_per_conversions_via_ad_click of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（クリック経由）/コンバージョン数（クリック経由）</div> <div lang=\"en\">Conv. value (via click)/conv. (via click)</div>   # noqa: E501

        :return: The value_per_conversions_via_ad_click of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._value_per_conversions_via_ad_click

    @value_per_conversions_via_ad_click.setter
    def value_per_conversions_via_ad_click(self, value_per_conversions_via_ad_click):
        """Sets the value_per_conversions_via_ad_click of this Stats.

        <div lang=\"ja\">コンバージョンの価値（クリック経由）/コンバージョン数（クリック経由）</div> <div lang=\"en\">Conv. value (via click)/conv. (via click)</div>   # noqa: E501

        :param value_per_conversions_via_ad_click: The value_per_conversions_via_ad_click of this Stats.  # noqa: E501
        :type: str
        """

        self._value_per_conversions_via_ad_click = value_per_conversions_via_ad_click

    @property
    def cpa_via_ad_click(self):
        """Gets the cpa_via_ad_click of this Stats.  # noqa: E501

        <div lang=\"ja\">コスト/コンバージョン数（クリック経由）</div> <div lang=\"en\">Cost/conv. (via click)</div>   # noqa: E501

        :return: The cpa_via_ad_click of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._cpa_via_ad_click

    @cpa_via_ad_click.setter
    def cpa_via_ad_click(self, cpa_via_ad_click):
        """Sets the cpa_via_ad_click of this Stats.

        <div lang=\"ja\">コスト/コンバージョン数（クリック経由）</div> <div lang=\"en\">Cost/conv. (via click)</div>   # noqa: E501

        :param cpa_via_ad_click: The cpa_via_ad_click of this Stats.  # noqa: E501
        :type: str
        """

        self._cpa_via_ad_click = cpa_via_ad_click

    @property
    def all_cpa(self):
        """Gets the all_cpa of this Stats.  # noqa: E501

        <div lang=\"ja\">コスト/コンバージョン数（全て）</div> <div lang=\"en\">Cost/conv. (all)</div>   # noqa: E501

        :return: The all_cpa of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._all_cpa

    @all_cpa.setter
    def all_cpa(self, all_cpa):
        """Sets the all_cpa of this Stats.

        <div lang=\"ja\">コスト/コンバージョン数（全て）</div> <div lang=\"en\">Cost/conv. (all)</div>   # noqa: E501

        :param all_cpa: The all_cpa of this Stats.  # noqa: E501
        :type: str
        """

        self._all_cpa = all_cpa

    @property
    def cross_device_conversions(self):
        """Gets the cross_device_conversions of this Stats.  # noqa: E501

        <div lang=\"ja\">クロスデバイスコンバージョン数</div> <div lang=\"en\">Cross-device conv.</div>   # noqa: E501

        :return: The cross_device_conversions of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._cross_device_conversions

    @cross_device_conversions.setter
    def cross_device_conversions(self, cross_device_conversions):
        """Sets the cross_device_conversions of this Stats.

        <div lang=\"ja\">クロスデバイスコンバージョン数</div> <div lang=\"en\">Cross-device conv.</div>   # noqa: E501

        :param cross_device_conversions: The cross_device_conversions of this Stats.  # noqa: E501
        :type: int
        """

        self._cross_device_conversions = cross_device_conversions

    @property
    def avg_deliver_rank(self):
        """Gets the avg_deliver_rank of this Stats.  # noqa: E501

        <div lang=\"ja\">平均掲載順位（配信された時のeCPM順位の平均）</div> <div lang=\"en\">Avg. position (the average of eCPM rank on ads delivery)</div>   # noqa: E501

        :return: The avg_deliver_rank of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._avg_deliver_rank

    @avg_deliver_rank.setter
    def avg_deliver_rank(self, avg_deliver_rank):
        """Sets the avg_deliver_rank of this Stats.

        <div lang=\"ja\">平均掲載順位（配信された時のeCPM順位の平均）</div> <div lang=\"en\">Avg. position (the average of eCPM rank on ads delivery)</div>   # noqa: E501

        :param avg_deliver_rank: The avg_deliver_rank of this Stats.  # noqa: E501
        :type: float
        """

        self._avg_deliver_rank = avg_deliver_rank

    @property
    def measured_imps(self):
        """Gets the measured_imps of this Stats.  # noqa: E501

        <div lang=\"ja\">メジャードインプレッション数</div> <div lang=\"en\">Measured impressions</div>   # noqa: E501

        :return: The measured_imps of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._measured_imps

    @measured_imps.setter
    def measured_imps(self, measured_imps):
        """Sets the measured_imps of this Stats.

        <div lang=\"ja\">メジャードインプレッション数</div> <div lang=\"en\">Measured impressions</div>   # noqa: E501

        :param measured_imps: The measured_imps of this Stats.  # noqa: E501
        :type: float
        """

        self._measured_imps = measured_imps

    @property
    def total_vimps(self):
        """Gets the total_vimps of this Stats.  # noqa: E501

        <div lang=\"ja\">メジャードインプレッション数（旧）</div> <div lang=\"en\">Measured impressions (previous)</div>   # noqa: E501

        :return: The total_vimps of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._total_vimps

    @total_vimps.setter
    def total_vimps(self, total_vimps):
        """Sets the total_vimps of this Stats.

        <div lang=\"ja\">メジャードインプレッション数（旧）</div> <div lang=\"en\">Measured impressions (previous)</div>   # noqa: E501

        :param total_vimps: The total_vimps of this Stats.  # noqa: E501
        :type: int
        """

        self._total_vimps = total_vimps

    @property
    def measured_imps_rate(self):
        """Gets the measured_imps_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">メジャードインプレッション測定率</div> <div lang=\"en\">Measured impression rate</div>   # noqa: E501

        :return: The measured_imps_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._measured_imps_rate

    @measured_imps_rate.setter
    def measured_imps_rate(self, measured_imps_rate):
        """Sets the measured_imps_rate of this Stats.

        <div lang=\"ja\">メジャードインプレッション測定率</div> <div lang=\"en\">Measured impression rate</div>   # noqa: E501

        :param measured_imps_rate: The measured_imps_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._measured_imps_rate = measured_imps_rate

    @property
    def vimps(self):
        """Gets the vimps of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルインプレッション数</div> <div lang=\"en\">Viewable impressions</div>   # noqa: E501

        :return: The vimps of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._vimps

    @vimps.setter
    def vimps(self, vimps):
        """Sets the vimps of this Stats.

        <div lang=\"ja\">ビューアブルインプレッション数</div> <div lang=\"en\">Viewable impressions</div>   # noqa: E501

        :param vimps: The vimps of this Stats.  # noqa: E501
        :type: int
        """

        self._vimps = vimps

    @property
    def viewable_imps_rate(self):
        """Gets the viewable_imps_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルインプレッション率</div> <div lang=\"en\">Viewable impression rate</div>   # noqa: E501

        :return: The viewable_imps_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._viewable_imps_rate

    @viewable_imps_rate.setter
    def viewable_imps_rate(self, viewable_imps_rate):
        """Sets the viewable_imps_rate of this Stats.

        <div lang=\"ja\">ビューアブルインプレッション率</div> <div lang=\"en\">Viewable impression rate</div>   # noqa: E501

        :param viewable_imps_rate: The viewable_imps_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._viewable_imps_rate = viewable_imps_rate

    @property
    def in_view_rate(self):
        """Gets the in_view_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルインプレッション率（旧）</div> <div lang=\"en\">Viewable impression rate (previous)</div>   # noqa: E501

        :return: The in_view_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._in_view_rate

    @in_view_rate.setter
    def in_view_rate(self, in_view_rate):
        """Sets the in_view_rate of this Stats.

        <div lang=\"ja\">ビューアブルインプレッション率（旧）</div> <div lang=\"en\">Viewable impression rate (previous)</div>   # noqa: E501

        :param in_view_rate: The in_view_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._in_view_rate = in_view_rate

    @property
    def viewable_clicks(self):
        """Gets the viewable_clicks of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルクリック数</div> <div lang=\"en\">Viewable clicks</div>   # noqa: E501

        :return: The viewable_clicks of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._viewable_clicks

    @viewable_clicks.setter
    def viewable_clicks(self, viewable_clicks):
        """Sets the viewable_clicks of this Stats.

        <div lang=\"ja\">ビューアブルクリック数</div> <div lang=\"en\">Viewable clicks</div>   # noqa: E501

        :param viewable_clicks: The viewable_clicks of this Stats.  # noqa: E501
        :type: float
        """

        self._viewable_clicks = viewable_clicks

    @property
    def in_view_click_cnt(self):
        """Gets the in_view_click_cnt of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルクリック数（旧）</div> <div lang=\"en\">Viewable clicks (previous)</div>   # noqa: E501

        :return: The in_view_click_cnt of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._in_view_click_cnt

    @in_view_click_cnt.setter
    def in_view_click_cnt(self, in_view_click_cnt):
        """Sets the in_view_click_cnt of this Stats.

        <div lang=\"ja\">ビューアブルクリック数（旧）</div> <div lang=\"en\">Viewable clicks (previous)</div>   # noqa: E501

        :param in_view_click_cnt: The in_view_click_cnt of this Stats.  # noqa: E501
        :type: int
        """

        self._in_view_click_cnt = in_view_click_cnt

    @property
    def viewable_click_rate(self):
        """Gets the viewable_click_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルクリック率</div> <div lang=\"en\">Viewable CTR</div>   # noqa: E501

        :return: The viewable_click_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._viewable_click_rate

    @viewable_click_rate.setter
    def viewable_click_rate(self, viewable_click_rate):
        """Sets the viewable_click_rate of this Stats.

        <div lang=\"ja\">ビューアブルクリック率</div> <div lang=\"en\">Viewable CTR</div>   # noqa: E501

        :param viewable_click_rate: The viewable_click_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._viewable_click_rate = viewable_click_rate

    @property
    def in_view_click_rate(self):
        """Gets the in_view_click_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルクリック率（旧）</div> <div lang=\"en\">Viewable CTR (previous)</div>   # noqa: E501

        :return: The in_view_click_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._in_view_click_rate

    @in_view_click_rate.setter
    def in_view_click_rate(self, in_view_click_rate):
        """Sets the in_view_click_rate of this Stats.

        <div lang=\"ja\">ビューアブルクリック率（旧）</div> <div lang=\"en\">Viewable CTR (previous)</div>   # noqa: E501

        :param in_view_click_rate: The in_view_click_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._in_view_click_rate = in_view_click_rate

    @property
    def paid_video_views(self):
        """Gets the paid_video_views of this Stats.  # noqa: E501

        <div lang=\"ja\">課金が発生した動画再生数 (CPV課金キャンペーンのみ)</div> <div lang=\"en\">Paid video views (CPV)</div>   # noqa: E501

        :return: The paid_video_views of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._paid_video_views

    @paid_video_views.setter
    def paid_video_views(self, paid_video_views):
        """Sets the paid_video_views of this Stats.

        <div lang=\"ja\">課金が発生した動画再生数 (CPV課金キャンペーンのみ)</div> <div lang=\"en\">Paid video views (CPV)</div>   # noqa: E501

        :param paid_video_views: The paid_video_views of this Stats.  # noqa: E501
        :type: int
        """

        self._paid_video_views = paid_video_views

    @property
    def paid_video_view_rate(self):
        """Gets the paid_video_view_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">課金が発生した動画再生率 (CPV課金キャンペーンのみ)</div> <div lang=\"en\">Paid video view rate (CPV)</div>   # noqa: E501

        :return: The paid_video_view_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._paid_video_view_rate

    @paid_video_view_rate.setter
    def paid_video_view_rate(self, paid_video_view_rate):
        """Sets the paid_video_view_rate of this Stats.

        <div lang=\"ja\">課金が発生した動画再生率 (CPV課金キャンペーンのみ)</div> <div lang=\"en\">Paid video view rate (CPV)</div>   # noqa: E501

        :param paid_video_view_rate: The paid_video_view_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._paid_video_view_rate = paid_video_view_rate

    @property
    def average_cpv(self):
        """Gets the average_cpv of this Stats.  # noqa: E501

        <div lang=\"ja\">平均CPV</div> <div lang=\"en\">Avg. CPV</div>   # noqa: E501

        :return: The average_cpv of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._average_cpv

    @average_cpv.setter
    def average_cpv(self, average_cpv):
        """Sets the average_cpv of this Stats.

        <div lang=\"ja\">平均CPV</div> <div lang=\"en\">Avg. CPV</div>   # noqa: E501

        :param average_cpv: The average_cpv of this Stats.  # noqa: E501
        :type: float
        """

        self._average_cpv = average_cpv

    @property
    def video_views(self):
        """Gets the video_views of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の再生開始数</div> <div lang=\"en\">Video views</div>   # noqa: E501

        :return: The video_views of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views

    @video_views.setter
    def video_views(self, video_views):
        """Sets the video_views of this Stats.

        <div lang=\"ja\">動画の再生開始数</div> <div lang=\"en\">Video views</div>   # noqa: E501

        :param video_views: The video_views of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views = video_views

    @property
    def video_views_to25(self):
        """Gets the video_views_to25 of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の25％再生数</div> <div lang=\"en\">25% video views</div>   # noqa: E501

        :return: The video_views_to25 of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to25

    @video_views_to25.setter
    def video_views_to25(self, video_views_to25):
        """Sets the video_views_to25 of this Stats.

        <div lang=\"ja\">動画の25％再生数</div> <div lang=\"en\">25% video views</div>   # noqa: E501

        :param video_views_to25: The video_views_to25 of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to25 = video_views_to25

    @property
    def video_views_to50(self):
        """Gets the video_views_to50 of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の50％再生数</div> <div lang=\"en\">50% video views</div>   # noqa: E501

        :return: The video_views_to50 of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to50

    @video_views_to50.setter
    def video_views_to50(self, video_views_to50):
        """Sets the video_views_to50 of this Stats.

        <div lang=\"ja\">動画の50％再生数</div> <div lang=\"en\">50% video views</div>   # noqa: E501

        :param video_views_to50: The video_views_to50 of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to50 = video_views_to50

    @property
    def video_views_to75(self):
        """Gets the video_views_to75 of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の75％再生数</div> <div lang=\"en\">75% video views</div>   # noqa: E501

        :return: The video_views_to75 of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to75

    @video_views_to75.setter
    def video_views_to75(self, video_views_to75):
        """Sets the video_views_to75 of this Stats.

        <div lang=\"ja\">動画の75％再生数</div> <div lang=\"en\">75% video views</div>   # noqa: E501

        :param video_views_to75: The video_views_to75 of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to75 = video_views_to75

    @property
    def video_views_to95(self):
        """Gets the video_views_to95 of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の95％再生数</div> <div lang=\"en\">95% video views</div>   # noqa: E501

        :return: The video_views_to95 of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to95

    @video_views_to95.setter
    def video_views_to95(self, video_views_to95):
        """Sets the video_views_to95 of this Stats.

        <div lang=\"ja\">動画の95％再生数</div> <div lang=\"en\">95% video views</div>   # noqa: E501

        :param video_views_to95: The video_views_to95 of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to95 = video_views_to95

    @property
    def video_views_to100(self):
        """Gets the video_views_to100 of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の100％再生数</div> <div lang=\"en\">100% video views</div>   # noqa: E501

        :return: The video_views_to100 of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to100

    @video_views_to100.setter
    def video_views_to100(self, video_views_to100):
        """Sets the video_views_to100 of this Stats.

        <div lang=\"ja\">動画の100％再生数</div> <div lang=\"en\">100% video views</div>   # noqa: E501

        :param video_views_to100: The video_views_to100 of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to100 = video_views_to100

    @property
    def video_views_to3_sec(self):
        """Gets the video_views_to3_sec of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の3秒再生数</div> <div lang=\"en\">3 sec video views</div>   # noqa: E501

        :return: The video_views_to3_sec of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to3_sec

    @video_views_to3_sec.setter
    def video_views_to3_sec(self, video_views_to3_sec):
        """Sets the video_views_to3_sec of this Stats.

        <div lang=\"ja\">動画の3秒再生数</div> <div lang=\"en\">3 sec video views</div>   # noqa: E501

        :param video_views_to3_sec: The video_views_to3_sec of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to3_sec = video_views_to3_sec

    @property
    def video_views_to10_sec(self):
        """Gets the video_views_to10_sec of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の10秒再生数</div> <div lang=\"en\">10 sec video views</div>   # noqa: E501

        :return: The video_views_to10_sec of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to10_sec

    @video_views_to10_sec.setter
    def video_views_to10_sec(self, video_views_to10_sec):
        """Sets the video_views_to10_sec of this Stats.

        <div lang=\"ja\">動画の10秒再生数</div> <div lang=\"en\">10 sec video views</div>   # noqa: E501

        :param video_views_to10_sec: The video_views_to10_sec of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to10_sec = video_views_to10_sec

    @property
    def average_rate_video_viewed(self):
        """Gets the average_rate_video_viewed of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の平均再生開始率</div> <div lang=\"en\">Avg. video view rate</div>   # noqa: E501

        :return: The average_rate_video_viewed of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._average_rate_video_viewed

    @average_rate_video_viewed.setter
    def average_rate_video_viewed(self, average_rate_video_viewed):
        """Sets the average_rate_video_viewed of this Stats.

        <div lang=\"ja\">動画の平均再生開始率</div> <div lang=\"en\">Avg. video view rate</div>   # noqa: E501

        :param average_rate_video_viewed: The average_rate_video_viewed of this Stats.  # noqa: E501
        :type: float
        """

        self._average_rate_video_viewed = average_rate_video_viewed

    @property
    def average_duration_video_viewed(self):
        """Gets the average_duration_video_viewed of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の平均再生時間</div> <div lang=\"en\">Avg. duration of video viewed</div>   # noqa: E501

        :return: The average_duration_video_viewed of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._average_duration_video_viewed

    @average_duration_video_viewed.setter
    def average_duration_video_viewed(self, average_duration_video_viewed):
        """Sets the average_duration_video_viewed of this Stats.

        <div lang=\"ja\">動画の平均再生時間</div> <div lang=\"en\">Avg. duration of video viewed</div>   # noqa: E501

        :param average_duration_video_viewed: The average_duration_video_viewed of this Stats.  # noqa: E501
        :type: float
        """

        self._average_duration_video_viewed = average_duration_video_viewed

    @property
    def impression_share(self):
        """Gets the impression_share of this Stats.  # noqa: E501

        <div lang=\"ja\">インプレッションシェア</div> <div lang=\"en\">Impression share</div>   # noqa: E501

        :return: The impression_share of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._impression_share

    @impression_share.setter
    def impression_share(self, impression_share):
        """Sets the impression_share of this Stats.

        <div lang=\"ja\">インプレッションシェア</div> <div lang=\"en\">Impression share</div>   # noqa: E501

        :param impression_share: The impression_share of this Stats.  # noqa: E501
        :type: float
        """

        self._impression_share = impression_share

    @property
    def budget_impression_share_lost_rate(self):
        """Gets the budget_impression_share_lost_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">インプレッションシェア損失率（予算）</div> <div lang=\"en\">Impression share lost rate(budget)</div>   # noqa: E501

        :return: The budget_impression_share_lost_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._budget_impression_share_lost_rate

    @budget_impression_share_lost_rate.setter
    def budget_impression_share_lost_rate(self, budget_impression_share_lost_rate):
        """Sets the budget_impression_share_lost_rate of this Stats.

        <div lang=\"ja\">インプレッションシェア損失率（予算）</div> <div lang=\"en\">Impression share lost rate(budget)</div>   # noqa: E501

        :param budget_impression_share_lost_rate: The budget_impression_share_lost_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._budget_impression_share_lost_rate = budget_impression_share_lost_rate

    @property
    def rank_impression_share_lost_rate(self):
        """Gets the rank_impression_share_lost_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">インプレッションシェア損失率（ランク）</div> <div lang=\"en\">Impression share lost rate(rank)</div>   # noqa: E501

        :return: The rank_impression_share_lost_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._rank_impression_share_lost_rate

    @rank_impression_share_lost_rate.setter
    def rank_impression_share_lost_rate(self, rank_impression_share_lost_rate):
        """Sets the rank_impression_share_lost_rate of this Stats.

        <div lang=\"ja\">インプレッションシェア損失率（ランク）</div> <div lang=\"en\">Impression share lost rate(rank)</div>   # noqa: E501

        :param rank_impression_share_lost_rate: The rank_impression_share_lost_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._rank_impression_share_lost_rate = rank_impression_share_lost_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Stats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Stats):
            return True

        return self.to_dict() != other.to_dict()
