# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class DictionaryServiceCategoryChild(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'str',
        'full_name': 'str',
        'name': 'str',
        'reach_desktop': 'int',
        'reach_smartphone': 'int',
        'reach_tablet': 'int'
    }

    attribute_map = {
        'code': 'code',
        'full_name': 'fullName',
        'name': 'name',
        'reach_desktop': 'reachDesktop',
        'reach_smartphone': 'reachSmartphone',
        'reach_tablet': 'reachTablet'
    }

    def __init__(self, code=None, full_name=None, name=None, reach_desktop=None, reach_smartphone=None, reach_tablet=None, local_vars_configuration=None):  # noqa: E501
        """DictionaryServiceCategoryChild - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._full_name = None
        self._name = None
        self._reach_desktop = None
        self._reach_smartphone = None
        self._reach_tablet = None
        self.discriminator = None

        self.code = code
        self.full_name = full_name
        self.name = name
        self.reach_desktop = reach_desktop
        self.reach_smartphone = reach_smartphone
        self.reach_tablet = reach_tablet

    @property
    def code(self):
        """Gets the code of this DictionaryServiceCategoryChild.  # noqa: E501

        <div lang=\"ja\">カテゴリコードです。</div> <div lang=\"en\">Category code.</div>   # noqa: E501

        :return: The code of this DictionaryServiceCategoryChild.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this DictionaryServiceCategoryChild.

        <div lang=\"ja\">カテゴリコードです。</div> <div lang=\"en\">Category code.</div>   # noqa: E501

        :param code: The code of this DictionaryServiceCategoryChild.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def full_name(self):
        """Gets the full_name of this DictionaryServiceCategoryChild.  # noqa: E501

        <div lang=\"ja\">カテゴリ名称です。（カテゴリ名称、サブカテゴリ名称を含めた正式名称です。）</div> <div lang=\"en\">Category name in high level.</div>   # noqa: E501

        :return: The full_name of this DictionaryServiceCategoryChild.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this DictionaryServiceCategoryChild.

        <div lang=\"ja\">カテゴリ名称です。（カテゴリ名称、サブカテゴリ名称を含めた正式名称です。）</div> <div lang=\"en\">Category name in high level.</div>   # noqa: E501

        :param full_name: The full_name of this DictionaryServiceCategoryChild.  # noqa: E501
        :type: str
        """

        self._full_name = full_name

    @property
    def name(self):
        """Gets the name of this DictionaryServiceCategoryChild.  # noqa: E501

        <div lang=\"ja\">サブカテゴリ名称です。</div> <div lang=\"en\">Category name.</div>   # noqa: E501

        :return: The name of this DictionaryServiceCategoryChild.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DictionaryServiceCategoryChild.

        <div lang=\"ja\">サブカテゴリ名称です。</div> <div lang=\"en\">Category name.</div>   # noqa: E501

        :param name: The name of this DictionaryServiceCategoryChild.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def reach_desktop(self):
        """Gets the reach_desktop of this DictionaryServiceCategoryChild.  # noqa: E501

        <div lang=\"ja\">PCのリーチ実績数です。</div> <div lang=\"en\">Reach record number of PC</div>   # noqa: E501

        :return: The reach_desktop of this DictionaryServiceCategoryChild.  # noqa: E501
        :rtype: int
        """
        return self._reach_desktop

    @reach_desktop.setter
    def reach_desktop(self, reach_desktop):
        """Sets the reach_desktop of this DictionaryServiceCategoryChild.

        <div lang=\"ja\">PCのリーチ実績数です。</div> <div lang=\"en\">Reach record number of PC</div>   # noqa: E501

        :param reach_desktop: The reach_desktop of this DictionaryServiceCategoryChild.  # noqa: E501
        :type: int
        """

        self._reach_desktop = reach_desktop

    @property
    def reach_smartphone(self):
        """Gets the reach_smartphone of this DictionaryServiceCategoryChild.  # noqa: E501

        <div lang=\"ja\">スマホのリーチ実績数です。</div> <div lang=\"en\">Reach record number of smartphone</div>   # noqa: E501

        :return: The reach_smartphone of this DictionaryServiceCategoryChild.  # noqa: E501
        :rtype: int
        """
        return self._reach_smartphone

    @reach_smartphone.setter
    def reach_smartphone(self, reach_smartphone):
        """Sets the reach_smartphone of this DictionaryServiceCategoryChild.

        <div lang=\"ja\">スマホのリーチ実績数です。</div> <div lang=\"en\">Reach record number of smartphone</div>   # noqa: E501

        :param reach_smartphone: The reach_smartphone of this DictionaryServiceCategoryChild.  # noqa: E501
        :type: int
        """

        self._reach_smartphone = reach_smartphone

    @property
    def reach_tablet(self):
        """Gets the reach_tablet of this DictionaryServiceCategoryChild.  # noqa: E501

        <div lang=\"ja\">タブレットのリーチ実績数です。</div> <div lang=\"en\">Reach record number of tablet</div>   # noqa: E501

        :return: The reach_tablet of this DictionaryServiceCategoryChild.  # noqa: E501
        :rtype: int
        """
        return self._reach_tablet

    @reach_tablet.setter
    def reach_tablet(self, reach_tablet):
        """Sets the reach_tablet of this DictionaryServiceCategoryChild.

        <div lang=\"ja\">タブレットのリーチ実績数です。</div> <div lang=\"en\">Reach record number of tablet</div>   # noqa: E501

        :param reach_tablet: The reach_tablet of this DictionaryServiceCategoryChild.  # noqa: E501
        :type: int
        """

        self._reach_tablet = reach_tablet

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DictionaryServiceCategoryChild):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DictionaryServiceCategoryChild):
            return True

        return self.to_dict() != other.to_dict()
