# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class FeedFtpRequestServiceOperation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'operand': 'list[FeedFtpRequest]'
    }

    attribute_map = {
        'account_id': 'accountId',
        'operand': 'operand'
    }

    def __init__(self, account_id=None, operand=None, local_vars_configuration=None):  # noqa: E501
        """FeedFtpRequestServiceOperation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._operand = None
        self.discriminator = None

        self.account_id = account_id
        self.operand = operand

    @property
    def account_id(self):
        """Gets the account_id of this FeedFtpRequestServiceOperation.  # noqa: E501

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">account Id</div>   # noqa: E501

        :return: The account_id of this FeedFtpRequestServiceOperation.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this FeedFtpRequestServiceOperation.

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">account Id</div>   # noqa: E501

        :param account_id: The account_id of this FeedFtpRequestServiceOperation.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and account_id is None:  # noqa: E501
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def operand(self):
        """Gets the operand of this FeedFtpRequestServiceOperation.  # noqa: E501


        :return: The operand of this FeedFtpRequestServiceOperation.  # noqa: E501
        :rtype: list[FeedFtpRequest]
        """
        return self._operand

    @operand.setter
    def operand(self, operand):
        """Sets the operand of this FeedFtpRequestServiceOperation.


        :param operand: The operand of this FeedFtpRequestServiceOperation.  # noqa: E501
        :type: list[FeedFtpRequest]
        """
        if self.local_vars_configuration.client_side_validation and operand is None:  # noqa: E501
            raise ValueError("Invalid value for `operand`, must not be `None`")  # noqa: E501

        self._operand = operand

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeedFtpRequestServiceOperation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FeedFtpRequestServiceOperation):
            return True

        return self.to_dict() != other.to_dict()
