# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.conversion_tracker_service_operation import ConversionTrackerServiceOperation  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestConversionTrackerServiceOperation(unittest.TestCase):
    """ConversionTrackerServiceOperation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ConversionTrackerServiceOperation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.conversion_tracker_service_operation.ConversionTrackerServiceOperation()  # noqa: E501
        if include_optional :
            return ConversionTrackerServiceOperation(
                account_id = 56,
                operand = [
                    yahoo_ads_display.models.conversion_tracker.ConversionTracker(
                        account_id = 56,
                        all_conversion_value = '0',
                        all_conversions = 56,
                        app_conversion = yahoo_ads_display.models.conversion_tracker_service_app_conversion.ConversionTrackerServiceAppConversion(
                            app_conversion_platform = 'ITUNES',
                            app_conversion_type = 'FIRST_OPEN',
                            app_id = '0', ),
                        category = 'NONE',
                        conversion_tracker_id = 56,
                        conversion_tracker_name = '0',
                        conversion_tracker_type = 'WEB_CONVERSION',
                        conversion_value = '0',
                        conversion_value_via_ad_click = '0',
                        conversions = 56,
                        conversions_via_ad_click = 56,
                        counting_type = 'ONE_PER_CLICK',
                        cross_device_conversions = 56,
                        exclude_from_bidding = 'FALSE',
                        measurement_period = 56,
                        measurement_period_view = 56,
                        most_recent_conversion_date = '0',
                        status = 'ENABLED',
                        user_revenue_value = 56,
                        web_conversion = yahoo_ads_display.models.conversion_tracker_service_web_conversion.ConversionTrackerServiceWebConversion(
                            snippet = [
                                yahoo_ads_display.models.conversion_tracker_service_web_conversion_snippet.ConversionTrackerServiceWebConversionSnippet(
                                    tag = '0',
                                    web_conversion_snippet_type = 'IMG', )
                                ], ), )
                    ]
            )
        else :
            return ConversionTrackerServiceOperation(
                account_id = 56,
                operand = [
                    yahoo_ads_display.models.conversion_tracker.ConversionTracker(
                        account_id = 56,
                        all_conversion_value = '0',
                        all_conversions = 56,
                        app_conversion = yahoo_ads_display.models.conversion_tracker_service_app_conversion.ConversionTrackerServiceAppConversion(
                            app_conversion_platform = 'ITUNES',
                            app_conversion_type = 'FIRST_OPEN',
                            app_id = '0', ),
                        category = 'NONE',
                        conversion_tracker_id = 56,
                        conversion_tracker_name = '0',
                        conversion_tracker_type = 'WEB_CONVERSION',
                        conversion_value = '0',
                        conversion_value_via_ad_click = '0',
                        conversions = 56,
                        conversions_via_ad_click = 56,
                        counting_type = 'ONE_PER_CLICK',
                        cross_device_conversions = 56,
                        exclude_from_bidding = 'FALSE',
                        measurement_period = 56,
                        measurement_period_view = 56,
                        most_recent_conversion_date = '0',
                        status = 'ENABLED',
                        user_revenue_value = 56,
                        web_conversion = yahoo_ads_display.models.conversion_tracker_service_web_conversion.ConversionTrackerServiceWebConversion(
                            snippet = [
                                yahoo_ads_display.models.conversion_tracker_service_web_conversion_snippet.ConversionTrackerServiceWebConversionSnippet(
                                    tag = '0',
                                    web_conversion_snippet_type = 'IMG', )
                                ], ), )
                    ],
        )

    def testConversionTrackerServiceOperation(self):
        """Test ConversionTrackerServiceOperation"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
