# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "yahoo-ads-display"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    &lt;div lang&#x3D;\&quot;ja\&quot;&gt;Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。&lt;br&gt; 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに&lt;br&gt; https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 &lt;/div&gt; &lt;div lang&#x3D;\&quot;en\&quot;&gt;Display Ads API Web Services supported in Yahoo! Ads API.&lt;br&gt; When you use \&quot;Try it out\&quot;, you need to register your application in advance.&lt;br&gt; As one of redirect URI for application, you need to set \&quot;https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\&quot;. &lt;/div&gt;   # noqa: E501
    """
)
