# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.ad_group_ad_service_page import AdGroupAdServicePage  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestAdGroupAdServicePage(unittest.TestCase):
    """AdGroupAdServicePage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AdGroupAdServicePage
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.ad_group_ad_service_page.AdGroupAdServicePage()  # noqa: E501
        if include_optional :
            return AdGroupAdServicePage(
                total_num_entries = 56,
                values = [
                    yahoo_ads_display.models.ad_group_ad_service_value.AdGroupAdServiceValue(
                        ad_group_ad = yahoo_ads_display.models.ad_group_ad.AdGroupAd(
                            account_id = 56,
                            ad = yahoo_ads_display.models.ad_group_ad_service_ad.AdGroupAdServiceAd(
                                ad_type = 'TEXT_LONG_AD1',
                                banner_image_ad = yahoo_ads_display.models.ad_group_ad_service_banner_image_ad.AdGroupAdServiceBannerImageAd(
                                    display_url = '0',
                                    url = '0', ),
                                banner_video_ad = yahoo_ads_display.models.ad_group_ad_service_banner_video_ad.AdGroupAdServiceBannerVideoAd(
                                    display_url = '0',
                                    is_remove_video10_sec_beacon_urls = 'TRUE',
                                    is_remove_video25_percent_beacon_urls = 'TRUE',
                                    is_remove_video3_sec_beacon_urls = 'TRUE',
                                    is_remove_video50_percent_beacon_urls = 'TRUE',
                                    is_remove_video75_percent_beacon_urls = 'TRUE',
                                    is_remove_video_complete_beacon_urls = 'TRUE',
                                    is_remove_video_start_beacon_urls = 'TRUE',
                                    thumbnail_media_id = 56,
                                    url = '0',
                                    video10_sec_beacon_urls = [
                                        '0'
                                        ],
                                    video25_percent_beacon_urls = [
                                        '0'
                                        ],
                                    video3_sec_beacon_urls = [
                                        '0'
                                        ],
                                    video50_percent_beacon_urls = [
                                        '0'
                                        ],
                                    video75_percent_beacon_urls = [
                                        '0'
                                        ],
                                    video_complete_beacon_urls = [
                                        '0'
                                        ],
                                    video_start_beacon_urls = [
                                        '0'
                                        ], ),
                                dynamic_ad = yahoo_ads_display.models.ad_group_ad_service_dynamic_ad.AdGroupAdServiceDynamicAd(
                                    brand_color = '0',
                                    button_text = 'FOR_MORE_INFO',
                                    campaign_banner_media_id = 56,
                                    campaign_banner_media_id2 = 56,
                                    campaign_banner_media_id3 = 56,
                                    campaign_banner_media_id4 = 56,
                                    campaign_banner_url = '0',
                                    display_url = '0',
                                    is_remove_campaign_banner_media_id = 'TRUE',
                                    is_remove_campaign_banner_media_id2 = 'TRUE',
                                    is_remove_campaign_banner_media_id3 = 'TRUE',
                                    is_remove_campaign_banner_media_id4 = 'TRUE',
                                    is_remove_campaign_banner_url = 'TRUE',
                                    logo_media_id = 56,
                                    logo_media_id2 = 56,
                                    logo_media_id3 = 56,
                                    prefix = '0',
                                    principal = '0',
                                    suffix = '0',
                                    url = '0', ),
                                mobile_ad = yahoo_ads_display.models.ad_group_ad_service_mobile_ad.AdGroupAdServiceMobileAd(
                                    description = '0',
                                    description2 = '0',
                                    display_url = '0',
                                    headline = '0',
                                    mobile_carriers = [
                                        'DOCOMO'
                                        ],
                                    url = '0', ),
                                pos_ad = yahoo_ads_display.models.ad_group_ad_service_pos_ad.AdGroupAdServicePosAd(
                                    description = '0',
                                    url = '0', ),
                                responsive_image_ad = yahoo_ads_display.models.ad_group_ad_service_responsive_image_ad.AdGroupAdServiceResponsiveImageAd(
                                    description = '0',
                                    display_url = '0',
                                    headline = '0',
                                    logo_media_id = 56,
                                    principal = '0',
                                    url = '0', ),
                                responsive_video_ad = yahoo_ads_display.models.ad_group_ad_service_responsive_video_ad.AdGroupAdServiceResponsiveVideoAd(
                                    description = '0',
                                    display_url = '0',
                                    headline = '0',
                                    logo_media_id = 56,
                                    principal = '0',
                                    thumbnail_media_id = 56,
                                    url = '0', ),
                                static_frame_ad = yahoo_ads_display.models.ad_group_ad_service_static_frame_ad.AdGroupAdServiceStaticFrameAd(
                                    color_set_id = 56,
                                    description = '0',
                                    display_url = '0',
                                    headline = '0',
                                    layout = '0',
                                    logo_media_id = 56,
                                    principal = '0',
                                    size = '0',
                                    url = '0', ),
                                text_ad = yahoo_ads_display.models.ad_group_ad_service_text_ad.AdGroupAdServiceTextAd(
                                    description = '0',
                                    description2 = '0',
                                    display_url = '0',
                                    headline = '0',
                                    url = '0', ), ),
                            ad_group_id = 56,
                            ad_group_name = '0',
                            ad_id = 56,
                            ad_name = '0',
                            ad_style = 'TEXT',
                            approval_status = 'APPROVED',
                            bid = yahoo_ads_display.models.ad_group_ad_service_bid.AdGroupAdServiceBid(
                                bidding_strategy_type = 'MANUAL_CPC',
                                manual_cpc_ad_group_ad_bid = yahoo_ads_display.models.ad_group_ad_service_manual_cpc_ad_group_ad_bid.AdGroupAdServiceManualCPCAdGroupAdBid(
                                    max_cpc = 56, ),
                                manual_cpv_ad_group_ad_bid = yahoo_ads_display.models.ad_group_ad_service_manual_cpv_ad_group_ad_bid.AdGroupAdServiceManualCPVAdGroupAdBid(
                                    max_cpv = 56, ), ),
                            campaign_id = 56,
                            campaign_name = '0',
                            disapproval_reason_codes = [
                                '0'
                                ],
                            impression_beacon_urls = [
                                '0'
                                ],
                            is_remove_beacon_urls = 'TRUE',
                            is_remove_third_party_tracking_script_url = 'TRUE',
                            labels = [
                                yahoo_ads_display.models.ad_group_ad_service_label.AdGroupAdServiceLabel(
                                    color = '0',
                                    description = '0',
                                    label_id = 56,
                                    label_name = '0', )
                                ],
                            media_id = 56,
                            third_party_tracking_script_url = '0',
                            third_party_tracking_vendor = '0',
                            user_status = 'ACTIVE', ),
                        errors = [
                            yahoo_ads_display.models.error.Error(
                                code = '0',
                                message = '0',
                                details = [
                                    yahoo_ads_display.models.error_detail.ErrorDetail(
                                        request_key = '0',
                                        request_value = '0', )
                                    ], )
                            ],
                        operation_succeeded = True, )
                    ]
            )
        else :
            return AdGroupAdServicePage(
        )

    def testAdGroupAdServicePage(self):
        """Test AdGroupAdServicePage"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
